@@ -125,6 +125,9 @@ class GlusterfsShareDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             reserved_percentage=self.configuration.reserved_share_percentage,
             reserved_snapshot_percentage=(
                 self.configuration.reserved_share_from_snapshot_percentage
+                or self.configuration.reserved_share_percentage),
+            reserved_share_extend_percentage=(
+                self.configuration.reserved_share_extend_percentage
                 or self.configuration.reserved_share_percentage))
         super(GlusterfsShareDriver, self)._update_share_stats(data)
 
